@@ -1,8 +1,9 @@
 #!/bin/sh
 
-find . -name '*.svg' -exec xmllint --noout {} + 2> xmlerrors
+find . -type f -name '*.svg' -exec xmllint --noout {} + 2> xmlerrors
 if [ -s xmlerrors ]; then
     cat xmlerrors
     rm xmlerrors
     exit 1
 fi
+rm xmlerrors
